"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = Box;
exports.getBoxProps = getBoxProps;
var _react = _interopRequireDefault(require("react"));
var _propTypes = require("./props/propTypes");
var _defaultProps = require("./props/defaultProps");
var _utils = require("./utils");
var _LayoutModule = _interopRequireDefault(require("./Layout.module.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
/* eslint css-modules/no-unused-class: 0 */

/* eslint-disable  react/no-unused-prop-types*/

function getBoxClassNames(props) {
  var hidden = props.hidden,
    className = props.className,
    flexible = props.flexible,
    adjust = props.adjust,
    isFirst = props.isFirst,
    isLast = props.isLast,
    shrink = props.shrink,
    column = props.column,
    align = props.align,
    scroll = props.scroll,
    preventParentScroll = props.preventParentScroll;
  var modificators = [className];
  if (flexible && !adjust) {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'grow'));
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'basis'));
  } else if (flexible && adjust) {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'grow'));
  }
  if (isFirst) {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'first'));
  }
  if (isLast) {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'last'));
  }
  if (adjust) {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'basisAuto'));
  }
  if (shrink) {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'shrinkOn'));
  } else {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], 'shrinkOff'));
  }
  if (hidden) {
    hidden.forEach(function (key) {
      modificators.push((0, _utils.getClass)(_LayoutModule["default"], "hidden-screen-".concat(key)));
    });
  }
  if (column) {
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], "col-".concat(column)));
  }
  if (align) {
    var alignClassMapping = {
      start: 'selfStart',
      end: 'selfEnd',
      center: 'selfCenter'
    };
    var alignClass = alignClassMapping[align];
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], alignClass));
  }
  if (scroll) {
    var scrollClassMapping = {
      horizontal: 'scrollx',
      vertical: 'scrolly',
      both: 'scrollboth',
      none: 'scrollnone'
    };
    var scrollClass = scrollClassMapping[scroll];
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], scrollClass));
  }
  if (preventParentScroll) {
    var ParentScrollClassMapping = {
      horizontal: 'preventScrollBubbleX',
      vertical: 'preventScrollBubbleY',
      both: 'preventScrollBubbleBoth'
    };
    var parentScrollClass = ParentScrollClassMapping[preventParentScroll];
    modificators.push((0, _utils.getClass)(_LayoutModule["default"], parentScrollClass));
  }
  return modificators;
}
function getBoxProps(props) {
  return (0, _utils.createProps)(_propTypes.BoxProps, props, getBoxClassNames(props));
}
function Box(props) {
  var childProps = getBoxProps(props);
  var tagName = props.tagName;
  (0, _utils.setProps)(childProps, props, {
    isScrollAttribute: 'data-scroll',
    eleRef: 'ref',
    dataId: 'data-id',
    tourId: 'data-tour',
    dataSelectorId: 'data-selector-id'
  });
  return /*#__PURE__*/_react["default"].createElement(tagName, childProps);
}
Box.propTypes = _propTypes.BoxProps;
Box.defaultProps = _defaultProps.BoxDefaultProps;